pub struct TofDetectorStatus {
pub channels000_031: u32,
pub channels032_063: u32,
pub channels064_095: u32,
pub channels096_127: u32,
pub channels128_159: u32,
pub channels160_191: u32,
pub channels192_223: u32,
pub channels224_255: u32,
pub channels256_297: u32,
pub channels298_319: u32,
}Expand description
Report dead channels/non-active detectors for the TOF system
This is a very simple approach A channels are the paddle_id - 1 while B channels are encoded as paddle_id - 159
Dead channels will be 0, active channels will be 1
Fields
channels000_031: u32channels032_063: u32channels064_095: u32channels096_127: u32channels128_159: u32channels160_191: u32channels192_223: u32channels224_255: u32channels256_297: u32channels298_319: u32Implementations
Sourceimpl TofDetectorStatus
impl TofDetectorStatus
pub fn new() -> Self
Sourcepub fn update_from_map(&mut self, paddles: HashMap<u16, bool>)
pub fn update_from_map(&mut self, paddles: HashMap<u16, bool>)
Update the dead channel list form a HashMap with paddle information as it is created in the RB communication threads of liftof-cc
Sourcepub fn get_active_paddles_a(&self) -> Vec<u8> ⓘ
pub fn get_active_paddles_a(&self) -> Vec<u8> ⓘ
Get all paddle ids which have dead channels on the A-side
Sourcepub fn get_active_paddles_b(&self) -> Vec<u8> ⓘ
pub fn get_active_paddles_b(&self) -> Vec<u8> ⓘ
Get all paddle ids which have dead channels on the B-side